# Changemaker V5 - Apps & Services Documentation

This document provides an overview of all the applications and services included in the Changemaker V5 productivity suite, along with links to their documentation.

## Dashboard

### Homepage
- **Description**: Main dashboard for Changemaker V5
- **Documentation**: [Homepage Docs](https://gethomepage.dev/)
- **Local Access**: http://localhost:3010/
- **Details**: Homepage serves as your central command center, providing a unified dashboard to access all Changemaker services from one place. It features customizable layouts, service status monitoring, and bookmarks to frequently used pages, eliminating the need to remember numerous URLs.

## Essential Tools

### Code Server
- **Description**: Visual Studio Code in the browser
- **Documentation**: [Code Server Docs](https://coder.com/docs/code-server)
- **Local Access**: http://localhost:8888/
- **Details**: Code Server brings the power of VS Code to your browser, allowing you to develop and edit code from any device without local installation. This makes it perfect for quick edits to website content, fixing formatting issues, or developing from tablets or borrowed computers. The familiar VS Code interface includes extensions, syntax highlighting, and Git integration.

### Flatnotes
- **Description**: Simple note-taking app - connected directly to blog
- **Documentation**: [Flatnotes Docs](https://github.com/Dullage/Flatnotes)
- **Local Access**: http://localhost:8089/
- **Details**: Flatnotes offers distraction-free, markdown-based note-taking with automatic saving and powerful search. Perfect for capturing ideas that can be directly published to your blog without reformatting. Use it for drafting newsletters, documenting processes, or maintaining a knowledge base that's both private and publishable.

### Listmonk
- **Description**: Self-hosted newsletter and mailing list manager
- **Documentation**: [Listmonk Docs](https://listmonk.app/docs/)
- **Local Access**: http://localhost:9000/
- **Details**: Listmonk provides complete control over your email campaigns without subscription fees or content restrictions. Create segmented lists, design professional newsletters, track engagement metrics, and manage opt-ins/unsubscribes—all while keeping your audience data private. Perfect for consistent communication with supporters without the censorship risks or costs of commercial platforms.

### NocoDB
- **Description**: Open Source Airtable Alternative
- **Documentation**: [NocoDB Docs](https://docs.nocodb.com/)
- **Local Access**: http://localhost:8090/
- **Details**: NocoDB transforms any database into a smart spreadsheet with advanced features like forms, views, and automations. Use it to create volunteer signup systems, event management databases, or campaign tracking tools without subscription costs. Its familiar spreadsheet interface makes it accessible to non-technical users while providing the power of a relational database.

## Content Creation

### MkDocs - Material Theme
- **Description**: Static site generator and documentation builder
- **Documentation**: [MkDocs Docs](https://www.mkdocs.org/)
- **Local Access**: http://localhost:4000/
- **Details**: MkDocs with Material theme transforms simple markdown files into beautiful, professional documentation sites. Ideal for creating campaign websites, project documentation, or public-facing content that loads quickly and ranks well in search engines. The Material theme adds responsive design, dark mode, and advanced navigation features.

### Excalidraw
- **Description**: Virtual collaborative whiteboard for sketching and drawing
- **Documentation**: [Excalidraw Docs](https://github.com/excalidraw/excalidraw)
- **Local Access**: http://localhost:3333/
- **Details**: Excalidraw provides a virtual whiteboard for creating diagrams, flowcharts, or sketches with a hand-drawn feel. It's excellent for visual brainstorming, planning project workflows, or mapping out campaign strategies. Multiple people can collaborate in real-time, making it ideal for remote team planning sessions.

### Gitea
- **Description**: Lightweight self-hosted Git service
- **Documentation**: [Gitea Docs](https://docs.gitea.io/)
- **Local Access**: http://localhost:3030/
- **Details**: Gitea provides a complete code and document version control system similar to GitHub but fully under your control. Use it to track changes to campaign materials, collaborate on content development, manage website code, or maintain configuration files with full revision history. Multiple contributors can work together without overwriting each other's changes.

### OpenWebUI
- **Description**: Web interface for Ollama
- **Documentation**: [OpenWebUI Docs](https://docs.openwebui.com/)
- **Local Access**: http://localhost:3005/
- **Details**: OpenWebUI provides a user-friendly chat interface for interacting with your Ollama AI models. This makes AI accessible to non-technical team members for tasks like drafting responses, generating creative content, or researching topics. The familiar chat format allows anyone to leverage AI assistance without needing to understand the underlying technology.

## Community & Data

### Monica CRM
- **Description**: Personal relationship management system
- **Documentation**: [Monica Docs](https://www.monicahq.com/docs)
- **Local Access**: http://localhost:8085/
- **Details**: Monica CRM helps you maintain meaningful relationships by tracking interactions, important dates, and personal details about contacts. It's perfect for community organizers to remember conversation contexts, follow up appropriately, and nurture connections with supporters. Unlike corporate CRMs, Monica focuses on the human aspects of relationships rather than just sales metrics.

### Answer
- **Description**: Q&A platform for teams
- **Documentation**: [Answer Docs](https://answer.dev/docs)
- **Local Access**: http://localhost:9080/
- **Details**: Answer creates a knowledge-sharing community where team members or supporters can ask questions, provide solutions, and vote on the best responses. It builds an organized, searchable knowledge base that grows over time. Use it for internal team support, public FAQs, or gathering community input on initiatives while keeping valuable information accessible rather than buried in email threads.

### Ferdium
- **Description**: All-in-one messaging application
- **Documentation**: [Ferdium Docs](https://ferdium.org/help)
- **Local Access**: http://localhost:3002/
- **Details**: Ferdium consolidates all your communication platforms (Slack, Discord, WhatsApp, Telegram, etc.) into a single interface. This allows you to monitor and respond across channels without constantly switching applications. Perfect for community managers who need to maintain presence across multiple platforms without missing messages or getting overwhelmed.

### Rocket.Chat
- **Description**: Team collaboration platform with chat, channels, and video conferencing
- **Documentation**: [Rocket.Chat Docs](https://docs.rocket.chat/)
- **Local Access**: http://localhost:3004/
- **Details**: Rocket.Chat provides a complete communication platform for your team or community. Features include real-time chat, channels, direct messaging, file sharing, video calls, and integrations with other services. It's perfect for creating private discussion spaces, coordinating campaigns, or building community engagement. Unlike commercial platforms, you maintain full data sovereignty and control over user privacy.

## Development

### Ollama
- **Description**: Local AI model server for running large language models
- **Documentation**: [Ollama Docs](https://ollama.ai/docs)
- **Local Access**: http://localhost:11435/
- **Details**: Ollama runs powerful AI language models locally on your server, providing AI capabilities without sending sensitive data to third-party services. Use it for content generation, research assistance, or data analysis with complete privacy. Models run on your hardware, giving you full control over what AI can access and ensuring your information stays confidential.

### Portainer
- **Description**: Docker container management UI
- **Documentation**: [Portainer Docs](https://docs.portainer.io/)
- **Local Access**: https://localhost:9443/
- **Details**: Portainer simplifies Docker management with a visual interface for controlling containers, images, networks, and volumes. Instead of complex command-line operations, you can start/stop services, view logs, and manage resources through an intuitive UI, making system maintenance accessible to non-technical users.

### Mini-QR
- **Description**: QR Code Generator
- **Documentation**: [Mini-QR Docs](https://github.com/xbzbing/mini-qr)
- **Local Access**: http://localhost:8081/
- **Details**: Mini-QR enables you to quickly generate customizable QR codes for any URL, text, or contact information. Perfect for campaign materials, business cards, or event signage. Create codes that link to your digital materials without relying on third-party services that may track usage or expire.

### ConvertX
- **Description**: Self-hosted file conversion tool
- **Documentation**: [ConvertX GitHub](https://github.com/c4illin/convertx)
- **Local Access**: http://localhost:3100/
- **Details**: ConvertX provides a simple web interface for converting files between different formats. It supports a wide range of file types including documents, images, audio, and video. This enables you to maintain full control over your file conversions without relying on potentially insecure third-party services. Perfect for converting documents for campaigns, optimizing images for web use, or preparing media files for different platforms.

### n8n
- **Description**: Workflow automation platform
- **Documentation**: [n8n Docs](https://docs.n8n.io/)
- **Local Access**: http://localhost:5678/
- **Details**: n8n automates repetitive tasks by connecting your applications and services with visual workflows. You can create automations like sending welcome emails to new supporters, posting social media updates across platforms, or synchronizing contacts between databases—all without coding. This saves hours of manual work and ensures consistent follow-through on processes.

## Remote Access

When configured with Cloudflare Tunnels, you can access these services remotely at:

- Homepage: https://homepage.yourdomain.com
- Excalidraw: https://excalidraw.yourdomain.com
- Listmonk: https://listmonk.yourdomain.com
- Monica CRM: https://monica.yourdomain.com
- MkDocs: https://yourdomain.com
- Flatnotes: https://flatnotes.yourdomain.com
- Code Server: https://code-server.yourdomain.com
- Ollama: https://ollama.yourdomain.com
- OpenWebUI: https://open-web-ui.yourdomain.com
- Gitea: https://gitea.yourdomain.com
- Portainer: https://portainer.yourdomain.com
- Mini QR: https://mini-qr.yourdomain.com
- Ferdium: https://ferdium.yourdomain.com
- Answer: https://answer.yourdomain.com
- NocoDB: https://nocodb.yourdomain.com
- n8n: https://n8n.yourdomain.com
- ConvertX: https://convertx.yourdomain.com
- Rocket.Chat: https://rocket.yourdomain.com
