# n8n: Automate Your Workflows

n8n is a powerful workflow automation platform that allows you to connect different services and systems together without needing complex programming skills. Within Changemaker V5, it enables you to create automated processes that save time and ensure consistency across your operations.

## Key Features

* **Visual Workflow Builder**: Create automation flows using an intuitive drag-and-drop interface.
* **Pre-built Integrations**: Connect to hundreds of services including email, social media, databases, and more.
* **Custom Functionality**: Create your own nodes for custom integrations when needed.
* **Scheduling**: Run workflows on schedules or trigger them based on events.
* **Error Handling**: Configure what happens when steps fail, with options to retry or alert.
* **Self-hosted**: Keep your automation data and credentials completely under your control.
* **Credential Management**: Securely store and reuse authentication details for various services.

## Documentation

For more detailed information about n8n, visit the [official documentation](https://docs.n8n.io/).

## Getting Started with n8n

### Accessing n8n
1. **URL**: You can access n8n locally via `http://localhost:5678/` (or your configured external URL if set up).
2. **Authentication**: The first time you access n8n, you'll need to set up an account with admin credentials.

### Basic Usage

1. **Creating Your First Workflow**:
   * Click the "+" button in the top right to create a new workflow.
   * Add a trigger node (e.g., "Schedule" for time-based triggers or "Webhook" for event-based triggers).
   * Connect additional nodes for the actions you want to perform.
   * Save your workflow and activate it using the toggle at the top of the editor.

2. **Example Workflow: Automatic Welcome Emails**
   * Start with a "Webhook" node that triggers when a new contact is added to your system.
   * Connect to an "Email" node configured to send your welcome message.
   * Optionally, add a "Slack" or "Rocket.Chat" node to notify your team about the new contact.
   
3. **Common Use Cases**:
   * **Content Publishing**: Automatically post blog updates to social media channels.
   * **Data Synchronization**: Keep contacts in sync between different systems.
   * **Event Management**: Send reminders before events and follow-ups afterward.
   * **Monitoring**: Get notifications when important metrics change or thresholds are reached.
   * **Form Processing**: Automatically handle form submissions with confirmation emails and data storage.

### Integration with Other Changemaker Services

n8n works particularly well with other services in your Changemaker environment:

* **NocoDB**: Connect to your databases to automate record creation, updates, or data processing.
* **Listmonk**: Trigger email campaigns based on events or schedules.
* **Gitea**: Automate responses to code changes or issue creation.
* **Monica CRM**: Update contact records automatically when interactions occur.
* **Rocket.Chat**: Send automated notifications to team channels.

## Advanced Features

* **Error Handling**: Configure error workflows and retries for increased reliability.
* **Splitting and Merging**: Process multiple items in parallel and then combine results.
* **Expressions**: Use JavaScript expressions for dynamic data manipulation.
* **Webhooks**: Create endpoints that can receive data from external services.
* **Function Nodes**: Write custom JavaScript code for complex data transformations.
* **Cron Jobs**: Schedule workflows to run at specific intervals.

## Further Information

For more detailed information on creating complex workflows, available integrations, and best practices, please refer to the [official n8n Documentation](https://docs.n8n.io/).
